import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import cdktf._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@cdktf/provider-local", "0.1.56", __name__[0:-6], "provider-local@0.1.56.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
